==> rapid_widgets_library-0.2.46.tar.gz: lib/custom-image.dart <==
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

import 'custom-widget-provider/custom-services.dart';

Widget customImage(
  CustomImageContents data,
  void Function() onTapImage,
) {
  // return (data.autoResize)
  //     ? GestureDetector(
  //         onTap: () {
  //           return (onTapImage != null) ? onTapImage() : null;
  //         },
  //         child: data.captionAlignment == 'top' || data.captionAlignment == 'bottom'
  //             ? Container(
  //                 decoration: BoxDecoration(
  //                     color: data.color,
  //                     borderRadius: BorderRadius.all(Radius.circular(data.outerAreaBorderRadius)),
  //                     boxShadow: [
  //                       BoxShadow(
  //                           blurRadius: data.shadowBlur,
  //                           spreadRadius: data.shadowSize,
  //                           offset: Offset(data.horizontalElevation, data.verticalElevation),
  //                           color: data.shadowColor),
  //                     ]),
  //                 child: Column(
  //                   children: [
  //                     data.captionAlignment == 'top'
  //                         ? Column(children: [CaptionText(data), ImageWithOverlay(data)])
  //                         : Column(
  //                             children: [
  //                               ImageWithOverlay(data),
  //                               CaptionText(data),
  //                             ],
  //                           ),
  //                   ],
  //                 ))
  //             : Container(
  //                 decoration: BoxDecoration(
  //                     color: data.color,
  //                     borderRadius: BorderRadius.all(Radius.circular(data.outerAreaBorderRadius)),
  //                     boxShadow: [
  //                       BoxShadow(
  //                           blurRadius: data.shadowBlur,
  //                           spreadRadius: data.shadowSize,
  //                           offset: Offset(data.horizontalElevation, data.verticalElevation),
  //                           color: data.shadowColor),
  //                     ]),
  //                 child: data.captionAlignment == 'left'
  //                     ? Row(
  //                         children: [
  //                           CaptionText(data),
  //                           ImageWithOverlay(data),
  //                         ],
  //                       )
  //                     : Row(
  //                         children: [
  //                           ImageWithOverlay(data),
  //                           CaptionText(data),
  //                         ],
  //                       ),
  //               ))
  //     :
  return GestureDetector(
    onTap: () {
      return (onTapImage != null) ? onTapImage() : null;
    },
    child: data.captionAlignment == 'top' || data.captionAlignment == 'bottom'
        ? Container(
            // height: data.imageContainerHeight,
            width: data.imageContainerWidth,
            decoration: BoxDecoration(
                color: data.color,
                borderRadius: BorderRadius.all(Radius.circular(data.outerAreaBorderRadius)),
                boxShadow: [
                  BoxShadow(
                      blurRadius: data.shadowBlur,
                      spreadRadius: data.shadowSize,
                      offset: Offset(data.horizontalElevation, data.verticalElevation),
                      color: data.shadowColor),
                ]),
            child: Column(
              children: [
                data.captionAlignment == 'top'
                    ? Padding(
                        padding: EdgeInsets.only(
                            left: data.captionLeftPadding,
                            right: data.captionRightPadding,
                            top: data.captionTopPadding,
                            bottom: data.captionBottomPadding),
                        child: Text(data.caption.trim(),
                            style: GoogleFonts.getFont(
                              checkFonts(data.fontFamily),
                                fontSize: data.captionFontSize,
                                color: data.captionColor,
                            )),
                      )
                    : Text(''),
                Padding(
                  padding: EdgeInsets.only(
                      left: data.imageLeftPadding,
                      right: data.imageRightPadding,
                      top: data.imageTopPadding,
                      bottom: data.imageBottomPadding),
                  child: Container(
                      child: data.showoverlayText
                          ? Align(
                              alignment: data.overlayTextAlignment,
                              child: Text(data.overlayText,
                                  style: GoogleFonts.getFont(
                                    checkFonts(data.fontFamily),
                                      fontSize: data.overlayTextFontSize,
                                      color: data.overlayTextColor,
                                  )))
                          : Text(''),
                      height: data.height,
                      width: data.width,
                      decoration: new BoxDecoration(
                          borderRadius: BorderRadius.all(Radius.circular(data.imageBorderRadius)),
                          image: DecorationImage(
                              image: NetworkImage(data.src),
                              colorFilter: new ColorFilter.mode(
                                  data.color.withOpacity(data.imageOpacity), data.colorBlendMode),
                              fit: data.fit))),
                ),
                data.captionAlignment == 'bottom'
                    ? Text(data.caption.trim(),
                        style: GoogleFonts.getFont( checkFonts(data.fontFamily),
                            fontSize: data.captionFontSize,
                            color: data.captionColor,
                            ))
                    : Text(''),
              ],
            ),
          )
        : Container(
            height: data.imageContainerHeight,
            width: data.imageContainerWidth,
            decoration: BoxDecoration(
                color: data.color,
                borderRadius: BorderRadius.all(Radius.circular(data.outerAreaBorderRadius)),
                boxShadow: [
                  BoxShadow(
                      blurRadius: data.shadowBlur,
                      spreadRadius: data.shadowSize,
                      offset: Offset(data.horizontalElevation, data.verticalElevation),
                      color: data.shadowColor),
                ]),
            child: Row(
              children: [
                data.captionAlignment == 'left'
                    ? Padding(
                        padding: EdgeInsets.only(
                            left: data.captionLeftPadding,
                            right: data.captionRightPadding,
                            top: data.captionTopPadding,
                            bottom: data.captionBottomPadding),
                        child: Text(data.caption.trim(),
                            style: GoogleFonts.getFont( checkFonts(data.fontFamily),
                                fontSize: data.captionFontSize,
                                color: data.captionColor,
                                )),
                      )
                    : Text(''),
                Padding(
                  padding: EdgeInsets.only(
                      left: data.imageLeftPadding,
                      right: data.imageRightPadding,
                      top: data.imageTopPadding,
                      bottom: data.imageBottomPadding),
                  child: Container(
                      child: data.showoverlayText
                          ? Align(
                              alignment: data.overlayTextAlignment,
                              child: Text(data.overlayText,
                                  style: GoogleFonts.getFont( checkFonts(data.fontFamily),
                                      fontSize: data.overlayTextFontSize,
                                      color: data.overlayTextColor,
                                      )))
                          : Text(''),
                      height: data.height,
                      width: data.width,
                      decoration: new BoxDecoration(
                          borderRadius: BorderRadius.all(Radius.circular(data.imageBorderRadius)),
                          image: DecorationImage(
                              image: NetworkImage(data.src),
                              colorFilter: new ColorFilter.mode(
                                  data.color.withOpacity(data.imageOpacity), data.colorBlendMode),
                              fit: data.fit))),
                ),
                data.captionAlignment == 'right'
                    ? Padding(
                        padding: EdgeInsets.only(
                            left: data.captionLeftPadding,
                            right: data.captionRightPadding,
                            top: data.captionTopPadding,
                            bottom: data.captionBottomPadding),
                        child: Text(data.caption.trim(),
                            style: GoogleFonts.getFont( checkFonts(data.fontFamily),
                                fontSize: data.captionFontSize,
                                color: data.captionColor,
                                )),
                      )
                    : Text(''),
              ],
            ),
          ),
  );
}

Widget ImageWithOverlay(CustomImageContents data) {
  return Container(
    padding: EdgeInsets.only(
        left: data.imageLeftPadding,
        right: data.imageRightPadding,
        top: data.imageTopPadding,
        bottom: data.imageBottomPadding),
    child: Stack(
      children: <Widget>[
        ColorFiltered(
          colorFilter: ColorFilter.mode(data.color.withOpacity(data.imageOpacity), data.colorBlendMode),
          child: Image(
            image: NetworkImage(data.src),
            fit: BoxFit.fill,
            semanticLabel: data.semanticLabel,
          ),
        ),
        data.showoverlayText
            ? Align(
                alignment: data.overlayTextAlignment,
                child: Text(data.overlayText,
                    style: GoogleFonts.getFont( checkFonts(data.fontFamily),
                        fontSize: data.overlayTextFontSize,
                        color: data.overlayTextColor,
                        )))
            : SizedBox.shrink(),
      ],
    ),
  );
}

Widget CaptionText(CustomImageContents data) {
  return Padding(
    padding: EdgeInsets.only(
        left: data.captionLeftPadding,
        right: data.captionRightPadding,
        top: data.captionTopPadding,
        bottom: data.captionBottomPadding),
    child: Text(data.caption.trim(),
        style: GoogleFonts.getFont(  checkFonts(data.fontFamily),
            fontSize: data.captionFontSize, color: data.captionColor,)),
  );
}

==> rapid_widgets_library-0.2.52.tar.gz: lib/custom-image.dart <==
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:transparent_image/transparent_image.dart';

import 'custom-widget-provider/custom-services.dart';

Widget customImage(
  CustomImageContents data,
  void Function() onTapImage,
) {
  // return (data.autoResize)
  //     ? GestureDetector(
  //         onTap: () {
  //           return (onTapImage != null) ? onTapImage() : null;
  //         },
  //         child: data.captionAlignment == 'top' || data.captionAlignment == 'bottom'
  //             ? Container(
  //                 decoration: BoxDecoration(
  //                     color: data.color,
  //                     borderRadius: BorderRadius.all(Radius.circular(data.outerAreaBorderRadius)),
  //                     boxShadow: [
  //                       BoxShadow(
  //                           blurRadius: data.shadowBlur,
  //                           spreadRadius: data.shadowSize,
  //                           offset: Offset(data.horizontalElevation, data.verticalElevation),
  //                           color: data.shadowColor),
  //                     ]),
  //                 child: Column(
  //                   children: [
  //                     data.captionAlignment == 'top'
  //                         ? Column(children: [CaptionText(data), ImageWithOverlay(data)])
  //                         : Column(
  //                             children: [
  //                               ImageWithOverlay(data),
  //                               CaptionText(data),
  //                             ],
  //                           ),
  //                   ],
  //                 ))
  //             : Container(
  //                 decoration: BoxDecoration(
  //                     color: data.color,
  //                     borderRadius: BorderRadius.all(Radius.circular(data.outerAreaBorderRadius)),
  //                     boxShadow: [
  //                       BoxShadow(
  //                           blurRadius: data.shadowBlur,
  //                           spreadRadius: data.shadowSize,
  //                           offset: Offset(data.horizontalElevation, data.verticalElevation),
  //                           color: data.shadowColor),
  //                     ]),
  //                 child: data.captionAlignment == 'left'
  //                     ? Row(
  //                         children: [
  //                           CaptionText(data),
  //                           ImageWithOverlay(data),
  //                         ],
  //                       )
  //                     : Row(
  //                         children: [
  //                           ImageWithOverlay(data),
  //                           CaptionText(data),
  //                         ],
  //                       ),
  //               ))
  //     :
  return GestureDetector(
    onTap: () {
      return (onTapImage != null) ? onTapImage() : null;
    },
    child: data.captionAlignment == 'top' || data.captionAlignment == 'bottom'
        ? Container(
            height: data.imageContainerHeight,
            width: data.imageContainerWidth,
            // color: data.imageContainerColor,
            decoration: BoxDecoration(
                color: data.color,
                borderRadius: BorderRadius.all(
                    Radius.circular(data.outerAreaBorderRadius)),
                border: Border.all(color: data.color,width: 0),
                boxShadow: [
                  BoxShadow(
                      blurRadius: data.shadowBlur,
                      spreadRadius: data.shadowSize,
                      offset: Offset(
                          data.horizontalElevation, data.verticalElevation),
                      color: data.shadowColor),
                ]),
            child: Column(
              children: [
                data.captionAlignment == 'top'
                    ? Padding(
                        padding: EdgeInsets.only(
                            left: data.captionLeftPadding,
                            right: data.captionRightPadding,
                            top: data.captionTopPadding,
                            bottom: data.captionBottomPadding),
                        child: Text(data.caption.trim(),
                            style: GoogleFonts.getFont(
                              checkFonts(data.fontFamily),
                              fontSize: data.captionFontSize,
                              color: data.captionColor,
                            )),
                      )
                    : Text(''),
                Padding(
                  padding: EdgeInsets.only(
                      left: data.imageLeftPadding,
                      right: data.imageRightPadding,
                      top: data.imageTopPadding,
                      bottom: data.imageBottomPadding),
                  child: data.colorBlendMode==BlendMode.multiply ?
                  FadeInImage.memoryNetwork(   // new line added
                    placeholder: kTransparentImage,   // new line added
                    image: data.src,   // new line added
                  ) : Container(
                      child: data.showoverlayText
                          ? Align(
                              alignment: data.overlayTextAlignment,
                              child: Text(data.overlayText,
                                  style: GoogleFonts.getFont(
                                    checkFonts(data.fontFamily),
                                    fontSize: data.overlayTextFontSize,
                                    color: data.overlayTextColor,
                                  )))
                          : Text(''),
                      height: data.height,
                      width: data.width,
                      decoration: new BoxDecoration(
                          borderRadius: BorderRadius.all(
                              Radius.circular(data.imageBorderRadius)),
                          border: Border.all(color: data.color,width: 0),
                          image: DecorationImage(
                              image: NetworkImage(data.src),
                              colorFilter: new ColorFilter.mode(
                                  data.color.withOpacity(data.imageOpacity),
                                  data.colorBlendMode),
                              fit: data.fit))),
                ),
                data.captionAlignment == 'bottom'
                    ? Text(data.caption.trim(),
                        style: GoogleFonts.getFont(
                          checkFonts(data.fontFamily),
                          fontSize: data.captionFontSize,
                          color: data.captionColor,
                        ))
                    : Text(''),
              ],
            ),
          )
        : Container(
            height: data.imageContainerHeight,
            width: data.imageContainerWidth,
            // color: data.imageContainerColor,
            decoration: BoxDecoration(
                color: data.color,
                borderRadius: BorderRadius.all(
                    Radius.circular(data.outerAreaBorderRadius)),
                border: Border.all(color: data.color,width: 0), //new line added
                boxShadow: [
                  BoxShadow(
                      blurRadius: data.shadowBlur,
                      spreadRadius: data.shadowSize,
                      offset: Offset(
                          data.horizontalElevation, data.verticalElevation),
                      color: data.shadowColor),
                ]),
            child: Row(
              children: [
                data.captionAlignment == 'left'
                    ? Padding(
                        padding: EdgeInsets.only(
                            left: data.captionLeftPadding,
                            right: data.captionRightPadding,
                            top: data.captionTopPadding,
                            bottom: data.captionBottomPadding),
                        child: Text(data.caption.trim(),
                            style: GoogleFonts.getFont(
                              checkFonts(data.fontFamily),
                              fontSize: data.captionFontSize,
                              color: data.captionColor,
                            )),
                      )
                    : Text(''),
                Padding(
                  padding: EdgeInsets.only(
                      left: data.imageLeftPadding,
                      right: data.imageRightPadding,
                      top: data.imageTopPadding,
                      bottom: data.imageBottomPadding),
                  child: data.colorBlendMode==BlendMode.multiply ?   // new line added
                        FadeInImage.memoryNetwork(   // new line added
                          placeholder: kTransparentImage,   // new line added
                          image: data.src,   // new line added
                        ) : Container(
                      child: data.showoverlayText
                          ? Align(
                              alignment: data.overlayTextAlignment,
                              child: Text(data.overlayText,
                                  style: GoogleFonts.getFont(
                                    checkFonts(data.fontFamily),
                                    fontSize: data.overlayTextFontSize,
                                    color: data.overlayTextColor,
                                  )))
                          : Text(''),
                      height: data.height,
                      width: data.width,
                      decoration: new BoxDecoration(
                          borderRadius: BorderRadius.all(
                              Radius.circular(data.imageBorderRadius)),
                          border: Border.all(color: data.color,width: 0),
                          image: DecorationImage(
                              image: NetworkImage(data.src),
                              colorFilter: new ColorFilter.mode(
                                  data.color.withOpacity(data.imageOpacity),
                                  data.colorBlendMode),
                              fit: data.fit))),
                ),
                data.captionAlignment == 'right'
                    ? Padding(
                        padding: EdgeInsets.only(
                            left: data.captionLeftPadding,
                            right: data.captionRightPadding,
                            top: data.captionTopPadding,
                            bottom: data.captionBottomPadding),
                        child: Text(data.caption.trim(),
                            style: GoogleFonts.getFont(
                              checkFonts(data.fontFamily),
                              fontSize: data.captionFontSize,
                              color: data.captionColor,
                            )),
                      )
                    : Text(''),
              ],
            ),
          ),
  );
}

Widget ImageWithOverlay(CustomImageContents data) {
  return Container(
    padding: EdgeInsets.only(
        left: data.imageLeftPadding,
        right: data.imageRightPadding,
        top: data.imageTopPadding,
        bottom: data.imageBottomPadding),
    child: Stack(
      children: <Widget>[
        ColorFiltered(
          colorFilter: ColorFilter.mode(
              data.color.withOpacity(data.imageOpacity), data.colorBlendMode),
          child: Image(
            image: NetworkImage(data.src),
            fit: BoxFit.fill,
            semanticLabel: data.semanticLabel,
          ),
        ),
        data.showoverlayText
            ? Align(
                alignment: data.overlayTextAlignment,
                child: Text(data.overlayText,
                    style: GoogleFonts.getFont(
                      checkFonts(data.fontFamily),
                      fontSize: data.overlayTextFontSize,
                      color: data.overlayTextColor,
                    )))
            : SizedBox.shrink(),
      ],
    ),
  );
}

Widget CaptionText(CustomImageContents data) {
  return Padding(
    padding: EdgeInsets.only(
        left: data.captionLeftPadding,
        right: data.captionRightPadding,
        top: data.captionTopPadding,
        bottom: data.captionBottomPadding),
    child: Text(data.caption.trim(),
        style: GoogleFonts.getFont(
          checkFonts(data.fontFamily),
          fontSize: data.captionFontSize,
          color: data.captionColor,
        )),
  );
}
